@@ -69,6 +69,8 @@ class AppImageListElement():
         os.chmod(self.file_path, 0o755)
         self.trusted = True
 
+    def get_config(self):
+        return read_config_for_app(self)
 
 class AppImageProvider():
     supported_mimes = ['application/x-iso9660-appimage', 'application/vnd.appimage', 'application/x-appimage']
@@ -701,7 +703,7 @@ class AppImageProvider():
 
             if use_unsquashfs:
                 logging.debug('Testing with unsquashfs')
-                appimage_offset = terminal.sandbox_sh(['/usr/lib/gearlever/get_appimage_offset', file.get_path()])
+                appimage_offset = terminal.sandbox_sh(['/usr/share/gearlever/get_appimage_offset', file.get_path()])
 
                 try:
                     terminal.sandbox_sh(['unsquashfs', '-o', appimage_offset, '-l', file.get_path()])
